@@ -21,6 +21,7 @@ import os
 import sys
 
 import pbr.version
+import yaml
 
 __version__ = pbr.version.VersionInfo('explode').version_string()
 
@@ -87,7 +88,7 @@ def main():
     try:
         data = json.loads(intext)
     except ValueError:
-        logging.error("Can't parse input data")
+        data = yaml.load(intext)
     explode_data(data, args.outdir)
 
 if __name__ == '__main__':
